%define liblcf_version %(echo %{version} | cut -d'.' -f-3)

Name:           easyrpg-player
Version:        0.6.2.3
Release:        %mkrel 1
Summary:        RPG Maker 2000/2003 and EasyRPG games interpreter
Group:          Games/Other
License:        GPLv3+
URL:            https://easyrpg.org
Source0:        https://easyrpg.org/downloads/player/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  icoutils
BuildRequires:  libtool
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(liblcf) >= %{liblcf_version}
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(ruby)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)

%description
EasyRPG Player is a game interpreter to play RPG Maker 2000, 2003 and
EasyRPG games. It uses liblcf to read RPG Maker game data.

It aims to be a free (as in freedom) cross-platform RPG Maker 2000/2003
interpreter. The main goal is to play all games created with them
as the original game interpreter (RPG_RT) does.

Run "%{name}" in the main directory of a RPG Maker 2000/2003
game project to launch it using EasyRPG.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_INSTALL_BINDIR=%{_gamesbindir}
%cmake_build

%install
%cmake_install

# Bash completion
# https://github.com/EasyRPG/Player/issues/2396
install -D -m644 resources/unix/bash-completion/easyrpg-player \
  %{buildroot}%{_datadir}/bash-completion/completions/%{name}

# Icon
mkdir -p %{buildroot}%{_iconsdir}/hicolor/48x48/apps
icotool -x -w48 resources/player.ico -o %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

# Menu entry - Not added for now since the executable has no GUI to browse to a game project
# mkdir -p %%{buildroot}%%{_datadir}/applications/
# cat > %%{buildroot}%%{_datadir}/applications/%%{name}.desktop << EOF
# [Desktop Entry]
# Encoding=UTF-8
# Name=EasyRPG Player
# Comment=%%{summary}
# Exec=%%{name}
# Icon=%%{name}
# Type=Application
# Categories=Game;RolePlaying;
# EOF

%files
%doc AUTHORS.md README.md
%license COPYING
#%%{_datadir}/applications/%%{name}.desktop
%{_datadir}/bash-completion/completions/%{name}
%{_gamesbindir}/%{name}
%{_iconsdir}/hicolor/48x48/apps/%{name}.png
%{_mandir}/man6/%{name}.6*


%changelog
* Mon Oct 12 2020 akien <akien> 0.6.2.3-1.mga8
+ Revision: 1633941
- Version 0.6.2.3

* Fri Feb 14 2020 umeabot <umeabot> 0.6.1-2.mga8
+ Revision: 1520030
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
+ akien <akien>
- Version 0.6.1

* Sat Nov 03 2018 daviddavid <daviddavid> 0.5.4-1.mga7
+ Revision: 1327979
- new version: 0.5.4
- remove merged upstream patch

* Sun Sep 23 2018 umeabot <umeabot> 0.5.3-2.mga7
+ Revision: 1297545
- Mageia 7 Mass Rebuild

* Sun Feb 04 2018 daviddavid <daviddavid> 0.5.3-1.mga7
+ Revision: 1198796
- new version: 0.5.3
- add upstream patch to fix build with sdl2_mixer 2.0.2

* Sat Jul 01 2017 akien <akien> 0.5.2-1.mga6
+ Revision: 1108791
- Version 0.5.2

* Wed Apr 12 2017 akien <akien> 0.5.1-1.mga6
+ Revision: 1096493
- Version 0.5.1

* Sat Oct 08 2016 akien <akien> 0.5.0-1.mga6
+ Revision: 1059638
- Version 0.5.0

* Sat Apr 02 2016 akien <akien> 0.4.1-1.mga6
+ Revision: 997639
- Version 0.4.1

* Mon Jan 04 2016 akien <akien> 0.4.0-1.mga6
+ Revision: 919395
- Version 0.4.0

* Mon Aug 31 2015 cjw <cjw> 0.2.2-2.mga6
+ Revision: 871558
- rebuild with gcc 5

* Sat Nov 29 2014 akien <akien> 0.2.2-1.mga5
+ Revision: 799951
- Version 0.2.2

* Wed Oct 15 2014 umeabot <umeabot> 0.2.1-3.mga5
+ Revision: 749535
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.1-2.mga5
+ Revision: 678910
- Mageia 5 Mass Rebuild

* Thu Jul 03 2014 akien <akien> 0.2.1-1.mga5
+ Revision: 642805
- Version 0.2.1

* Tue Jul 01 2014 akien <akien> 0.2-2.mga5
+ Revision: 641796
- Fix RPM group and URL

* Sat Jun 28 2014 akien <akien> 0.2-1.mga5
+ Revision: 640802
- imported package easyrpg-player

